<?php
namespace SupplyTek\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SupplyTek\Utilities\SessionHandler;
use Doctrine\ORM\EntityManager;

/**
 * Searches for supplier's logo
 *
 * @author Tarcisio Junior
 */
class AppController 
{
    protected $sessionHandler;
    protected $connection;
    protected $fileServerURL;

    /**
     * Class constructor
     * 
     * Initialize an object's properties upon creation of the object.
     * @param SessionHandler $sessionHandler Object that allows to manipulate session
     * @param EntityManager $entityManager Object that allows to manipulate the connection
     * 
     * @return void
     * 
     * @access public
     * @author Tarcisio Junior
     */
    public function __construct (SessionHandler $sessionHandler, EntityManager $entityManager, $fileServerURL) 
    {
        $this->sessionHandler = $sessionHandler;
        $this->connection = $entityManager->getConnection();
        $this->fileServerURL = $fileServerURL;
    }
    
    /**
     * Return the supplier's logo
     * 
     * @param Request $request Object that receives data from the caller
     * @param Response $response Object that sends back data to the caller
     *
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Tarcisio Junior
     */
    
    public function getLogoImage (Request $request, Response $response)
    {
        try {
            $path = null;
            $sql = "SELECT F.CDFILIAL, F.NMFILIAL, F2.CDFILIAL AS CDFILCENTCMP, F2.NMFILIAL AS NMFILCENTCMP, F2.NRORG FROM FILIAL F, FILIAL F2 WHERE F.CDFILIAL = :P_CDFILIAL AND F2.CDFILIAL = NVL(F.CDFILCENTCMP, F.CDFILIAL)";
            $params = array(
                "P_CDFILIAL" => $this->sessionHandler->getSessionData("CDFILIAL")
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            $result = $std->fetch();
        
            $sql2 = "SELECT DSDIRLOGOMARCA FROM PARASUPRI WHERE CDFILIAL = :P_CDFILIAL";
            $params2 = array(
                "P_CDFILIAL" => $result["CDFILCENTCMP"]
            );
            $std2 = $this->connection->prepare($sql2);
            $std2->execute($params2);
            $result2 = $std2->fetch();

            if($result2["DSDIRLOGOMARCA"] != null) {
                $path = $this->fileServerURL . $result2["DSDIRLOGOMARCA"];
            } else {
                $sql3 = "SELECT IDSISDOS FROM PARAMGERAL";
                $std3 = $this->connection->prepare($sql3);
                $std3->execute();
                $result3 = $std3->fetch();
                if($result3 && $result3["IDSISDOS"] == 3) {
                    $path = '/img/logo_GR.png';
                }
            }

            $imagePath = array (
                "pathImage" => $path
            );
            
            $response->addDataSet(new DataSet('logo', $imagePath));
        } catch(\Exception $e) {
            throw new \Exception ($e->getMessage(), $e->getCode());
        }
    }
}
